@@ -120,7 +120,7 @@ class BuildProject(object):
 
     def write_dependencies_cmake(self, sdk_dirs):
         """ Write the dependencies.cmake file. This will be read by
-        qibuild-config.cmake to set CMAKE_FIND_ROOT_PATH and
+        qibuild-config.cmake to set CMAKE_PREFIX_PATH and
         qibuild_DIR, so that just running `cmake ..` works
 
         """
@@ -146,9 +146,9 @@ endif()
 # Dependencies:
 {dep_to_add}
 
-# Store CMAKE_MODULE_PATH and CMAKE_FIND_ROOT_PATH in cache:
+# Store CMAKE_MODULE_PATH and CMAKE_PREFIX_PATH in cache:
 set(CMAKE_MODULE_PATH ${{CMAKE_MODULE_PATH}} CACHE INTERNAL ""  FORCE)
-set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
+set(CMAKE_PREFIX_PATH ${{CMAKE_PREFIX_PATH}} CACHE INTERNAL ""  FORCE)
 
 {custom_cmake_code}
 """
@@ -163,9 +163,9 @@ set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
         for sdk_dir in sdk_dirs:
 
             dep_to_add += """
-    list(FIND CMAKE_FIND_ROOT_PATH "{sdk_dir}" _found)
+    list(FIND CMAKE_PREFIX_PATH "{sdk_dir}" _found)
     if(_found STREQUAL "-1")
-        list(INSERT CMAKE_FIND_ROOT_PATH 0 "{sdk_dir}")
+        list(INSERT CMAKE_PREFIX_PATH 0 "{sdk_dir}")
     endif()
     """.format(sdk_dir=qisys.sh.to_posix_path(sdk_dir))
 
@@ -277,6 +277,7 @@ set(QIBUILD_PYTHON_PATH "%s" CACHE STRING "" FORCE)
             build_env = self.build_env.copy()
         else:
             build_env = env
+        build_env = self.fix_env(build_env)
         if self.verbose_make:
             if self.cmake_generator:
                 if "Makefiles" in self.cmake_generator:
@@ -426,6 +427,16 @@ set(QIBUILD_PYTHON_PATH "%s" CACHE STRING "" FORCE)
             qibuild.dlls.fix_dlls(self.sdk_directory, paths=paths,
                                   mingw=mingw, env=self.build_env)
 
+    def fix_env(self, env):
+        if sys.platform == "darwin":
+            # some projects run binaries during buildtime, they need this hack
+            # to find the toolchain libraries until we use cmake 2.8.12 on mac
+            lib_dir = os.path.join(self.sdk_directory, "lib")
+            envsetter = qisys.envsetter.EnvSetter(build_env=env)
+            envsetter.prepend_directory_to_variable(lib_dir, "DYLD_LIBRARY_PATH")
+            envsetter.prepend_directory_to_variable(self.sdk_directory, "DYLD_FRAMEWORK_PATH")
+            env = envsetter.get_build_env()
+        return env
 
     def split_debug(self, destdir):
         """ Split debug symbols after install """
